/* style.css */
body {
    font-family: Arial, sans-serif;
    background-color: #f4f4f4;
    margin: 0;
    padding: 0;
}

h1 {
    color: #333;
    text-align: center;
}

h2 {
    color: #333;
    text-align: center;
}

form {
    max-width: 400px;
    margin: 20px auto;
    padding: 20px;
    background-color: #fff;
    border-radius: 5px;
    box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
}

label {
    display: block;
    margin-bottom: 8px;
    color: #333;
}

input {
    width: 100%;
    padding: 8px;
    margin-bottom: 15px;
    box-sizing: border-box;
}

/*input[type="submit"] {*/
/*    background-color: #4caf50;*/
/*    color: #fff;*/
/*    cursor: pointer;*/
/*}*/

input[type="submit"]:hover {
    background-color: #45a049;
}

p {
    color: #777;
}

p, table {
    max-width: 1200px;
    margin: 20px auto;
    text-align: center;
}
table {
    width: 100%;
    border-collapse: collapse;
    margin-top: 20px;
}

th, td {
    border: 1px solid #ddd;
    padding: 8px;
    text-align: left;
}

th {
    background-color: #f2f2f2;
}

.alert {
    text-align: center;
}

.headline {
    display: flex;
    justify-content: center;
    align-items: center;
    gap: 50px;
    padding-top: 30px;
}

.container {
    display: flex;
    max-width: 600px;
    margin: 20px auto;
    padding: 20px;
    background-color: #fff;
    border-radius: 5px;
    box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
    align-items: center;
    justify-content: space-between;
}


.container button:hover {
    background-color: whitesmoke;
}